@@ -5,11 +5,11 @@
 
 import copy
 import pickle
+import itertools
 import abc
 
 import nose
 
-from python_toolbox import cute_iter_tools
 from python_toolbox import cute_testing
 from python_toolbox import import_tools
 from python_toolbox import queue_tools
@@ -42,7 +42,7 @@ def test():
     checkers = [_check_deepcopying, _check_process_passing]
     cross_process_persistent_classes = [A, CrossProcessPersistent]
     
-    yield from cute_iter_tools.product(
+    yield from itertools.product(
         checkers,
         cross_process_persistent_classes,
     )
@@ -166,7 +166,7 @@ def test_helpful_warnings_for_old_protocols():
     cross_process_persistents = [A(), CrossProcessPersistent()]
     old_protocols = [0, 1]
     
-    iterator = cute_iter_tools.product(
+    iterator = itertools.product(
         pickle_modules,
         cross_process_persistents,
         old_protocols
